function [ Area, Ix, Iy, J ] = Sec_Prop_Rect (Width, Height )
%Sec_Prop_Rect
%  This routine computes the second moments of inertia about the X and Y
%  axes and the second polar moment of inertia through the centroid.
%
%    Width    The width of the rectangle
%    Height   The height of the rectangle
%
%  Returns
%   Area   The area of the section
%   Ix     The second moment of inertia around X
%   Iy     The second moment of inertia around Y
%   J      The polar moment of inertia
%

Area = Height * Width;
Ix = (Width * Height ^ 3)/12;
Iy = (Height * Width ^ 3) /12;
J = Ix + Iy;
end

